# QALU
Quantum Arithmetic Logic Unit

<a href="https://raw.githubusercontent.com/alihakimtaskiran/QALU/main/qalu.py">Download QALU </a>

For Docs, <a href="https://github.com/alihakimtaskiran/QALU/blob/main/Docs/README.MD">cilck here</a>
|Function|Schema|Superposed State|
|--|-|--|
|**and_**(circ,a,b,out)|![](src/and_s_.png)|![](src/and_q.png)|
|**nand_**(circ,a,b,out)|![](src/nand_s_.png)|![](src/nand_q.png)|
|**or_**(circ,a,b,out)|![](src/or_s_.png)|![](src/or_q.png)|
|**nor_**(circ,a,b,out)|![](src/nor_s_.png)|![](src/nor_q.png)|
|**xor**_(circ,a,b,out)|![](src/xor_s_.png)|![](src/xor_q.png)|
|**xnor**_(circ,a,b,out)|![](src/xnor_s_.png)|![](src/xnor_qq.png)|
|**half_adder**(circ, a, b, carry,sum_)|![](src/ha_s_.png)|![](src/ha_q.png)|
|**full_adder**(circ,a,b,c_in,c_out,sum_)|![](src/fa_s__.png)|![](src/fa_q.png)|
|**half_subtractor**(circ, a, b, bor, diff)|![](src/hs_s_.png)|![](src/hs_q.png)|
|**full_subtractor**(circ,a,b,b_in,b_out,diff)|![](src/fs_s__.png)|![](src/fs_q.png)|
|**multi_qubits_adder**(circ,A,B,T,C)|![](src/mqa.png)|No state sphere provided|
|**multi_qubits_subtractor**(circ,A,B,T,C)|![](src/mqs.png)|No state sphere provided|

